==> 7.1.0.tar.gz: decort-ansible/wiki/7.1.0/Home.md <==
1. [Введение](./введение.md)
   - [Введение](./введение.md#введение)
   - [Системные требования](./введение.md#системные-требования)
   - [Подготовка к работе](./введение.md#подготовка-к-работе)
   - [Авторизация](./введение.md#авторизация)
      - [Общие параметры модулей для авторизации](./введение.md#общие-параметры-модулей-для-авторизации)
      - [Пример авторизации с помощью DECS3O](./введение.md#пример-авторизации-с-помощью-decs3o)
      - [Пример авторизации с помощью BVS](./введение.md#пример-авторизации-с-помощью-bvs)
      - [Пример авторизации с помощью JSON Web Token](./введение.md#пример-авторизации-с-помощью-json-web-token)
2. Ansible модули DECORT:
   - [Модуль decort_kvmvm](./модуль-decort_kvmvm.md) - управление виртуальными машинами
   - [Модуль decort_osimage](./модуль-decort_osimage.md) - управление образами
   - [Модуль decort_disk](./модуль-decort_disk.md) - управление дисками
   - [Модуль decort_pfw](./модуль-decort_pfw.md) - управление правилами переадресации портов
   - [Модуль decort_rg](./модуль-decort_rg.md) - управление ресурсными группами
   - [Модуль decort_vins](./модуль-decort_vins.md) - управление внутренними сетями
   - [Модуль decort_jwt](./модуль-decort_jwt.md) - получение авторизационного токена
   - [Модуль decort_bservice](./модуль-decort_bservice.md) - управление базовыми службами
   - [Модуль decort_group](./модуль-decort_group.md)- управление группами базовой службы
   - [Модуль decort_k8s](./модуль-decort_k8s.md) - управление кластерами Kubernetes
   - [Модуль decort_lb](./модуль-decort_lb.md) - управление балансировщиками нагрузки
   - [Модуль decort_account_info](./модуль-decort_account_info.md) - получение информации об аккаунте
   - [Модуль decort_account](./модуль-decort_account.md) - управление аккаунтами
   - [Модуль decort_user_info](./модуль-decort_user_info.md) - получение информации о пользователе
   - [Модуль decort_snapshot](./модуль-decort_snapshot.md) - управление снимками виртуальной машины

==> 7.2.0.tar.gz: decort-ansible/wiki/6.1.0/Home.md <==
1. [Введение](./введение.md)
   - [Введение](./введение.md#введение)
   - [Системные требования](./введение.md#системные-требования)
   - [Подготовка к работе](./введение.md#подготовка-к-работе)
   - [Авторизация](./введение.md#авторизация)
      - [Общие параметры модулей для авторизации](./введение.md#общие-параметры-модулей-для-авторизации)
      - [Пример авторизации с помощью app_id и app_secret](./введение.md#пример-авторизации-с-помощью-app_id-и-app_secret)
      - [Пример авторизации с помощью JSON Web Token](./введение.md#пример-авторизации-с-помощью-json-web-token)
1. Ansible модули DECORT:
   - [Модуль decort_kvmvm](./модуль-decort_kvmvm.md) - управление виртуальными машинами
   - [Модуль decort_osimage](./модуль-decort_osimage.md) - управление образами
   - [Модуль decort_disk](./модуль-decort_disk.md) - управление дисками
   - [Модуль decort_pfw](./модуль-decort_pfw.md) - управление правилами переадресации портов
   - [Модуль decort_rg](./модуль-decort_rg.md) - управление ресурсными группами
   - [Модуль decort_vins](./модуль-decort_vins.md) - управление внутренними сетями
   - [Модуль decort_jwt](./модуль-decort_jwt.md) - получение авторизационного токена
   - [Модуль decort_bservice](./модуль-decort_bservice.md) - управление базовыми службами
   - [Модуль decort_group](./модуль-decort_group.md)- управление группами базовой службы
   - [Модуль decort_k8s](./модуль-decort_k8s.md) - управление кластерами Kubernetes
   - [Модуль decort_lb](./модуль-decort_lb.md) - управление балансировщиками нагрузки
   - [Модуль decort_account_info](./модуль-decort_account_info.md) - получение информации об аккаунте
   - [Модуль decort_account](./модуль-decort_account.md) - управление аккаунтами
   - [Модуль decort_user_info](./модуль-decort_user_info.md) - получение информации о пользователе
